@@ -10,6 +10,7 @@ from .api import make_request, BASE_URL
 MAPS_ENDPOINT = urljoin(BASE_URL, "maps/")
 MAP_TEMPLATE = urljoin(MAPS_ENDPOINT, "{map_id}/")
 MAP_UPDATE_TEMPLATE = urljoin(MAPS_ENDPOINT, "{map_id}/update")
+MAP_MOVE_TEMPLATE = urljoin(MAPS_ENDPOINT, "{map_id}/move")
 
 
 def create_map(api_token: str | None = None, **json_args):
@@ -51,3 +52,14 @@ def update_map(map_id: str, new_title: str, api_token: str | None = None):
         api_token=api_token,
     )
     return json.load(response)
+
+
+def move_map(map_id: str, project_id: str, api_token: str | None = None):
+    """Move a map to a different project"""
+    response = make_request(
+        url=MAP_MOVE_TEMPLATE.format(map_id=map_id),
+        method="POST",
+        json={"project_id": project_id},
+        api_token=api_token,
+    )
+    return json.load(response)
